@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 NAME = 'team_center_api'
 
 # URL 定义
@@ -7,8 +5,11 @@ NAME = 'team_center_api'
 # 开放登录
 URL_USER_LOGIN = '/open/user/login'
 
+# 兑换token
+URL_USER_TOKEN_EXCHANGE = '/open/api/user/token/exchange'
+
 # 验证token
-URL_USER_TOKEN_AUTH = '/open/api/user/token/auth'
+URL_USER_TOKEN_VERIFY = '/open/api/user/token/verify'
 
 # 验证权限
 URL_USER_PERMISSION_VERIFY = '/open/api/user/permission/verify'
@@ -16,8 +17,5 @@ URL_USER_PERMISSION_VERIFY = '/open/api/user/permission/verify'
 # 获取所有权限
 URL_USER_PERMISSIONS_ALL = '/open/api/user/permissions/all'
 
-# 生成并发送PIN码
-URL_PIN_CREATE = '/open/api/pin/create'
-
 # 验证PIN码
 URL_PIN_VERIFY = '/open/api/pin/verify'
